@@ -2,12 +2,25 @@
 # SPDX-License-Identifier: MIT
 
 import collections
+import copy
 import re
 import urllib.parse
 from abc import ABC, abstractmethod
-from typing import TYPE_CHECKING, Iterable, List, Optional, Tuple, Union, cast, overload
+from typing import (
+    TYPE_CHECKING,
+    Any,
+    Dict,
+    Iterable,
+    List,
+    Optional,
+    Tuple,
+    Union,
+    cast,
+    overload,
+)
 
 from specfile.exceptions import DuplicateSourceException
+from specfile.formatter import formatted
 from specfile.macros import Macros
 from specfile.sourcelist import Sourcelist, SourcelistEntry
 from specfile.tags import Comments, Tag, Tags
@@ -84,11 +97,16 @@ class TagSource(Source):
         self._tag = tag
         self._number = number
 
+    def __eq__(self, other: object) -> bool:
+        if not isinstance(other, TagSource):
+            return NotImplemented
+        return self._tag == other._tag and self._number == other._number
+
+    @formatted
     def __repr__(self) -> str:
-        tag = repr(self._tag)
         # determine class name dynamically so that inherited classes
         # don't have to reimplement __repr__()
-        return f"{self.__class__.__name__}({tag}, {self._number})"
+        return f"{self.__class__.__name__}({self._tag!r}, {self._number!r})"
 
     def _extract_number(self) -> Optional[str]:
         """
@@ -174,11 +192,16 @@ class ListSource(Source):
         self._source = source
         self._number = number
 
+    def __eq__(self, other: object) -> bool:
+        if not isinstance(other, ListSource):
+            return NotImplemented
+        return self._source == other._source and self._number == other._number
+
+    @formatted
     def __repr__(self) -> str:
-        source = repr(self._source)
         # determine class name dynamically so that inherited classes
         # don't have to reimplement __repr__()
-        return f"{self.__class__.__name__}({source}, {self._number})"
+        return f"{self.__class__.__name__}({self._source!r}, {self._number!r})"
 
     @property
     def number(self) -> int:
@@ -252,18 +275,39 @@ class Sources(collections.abc.MutableSequence):
         self._default_source_number_digits = default_source_number_digits
         self._context = context
 
+    def __eq__(self, other: object) -> bool:
+        if not isinstance(other, Sources):
+            return NotImplemented
+        return (
+            self._tags == other._tags
+            and self._sourcelists == other._sourcelists
+            and self._allow_duplicates == other._allow_duplicates
+            and self._default_to_implicit_numbering
+            == other._default_to_implicit_numbering
+            and self._default_source_number_digits
+            == other._default_source_number_digits
+        )
+
+    @formatted
     def __repr__(self) -> str:
-        tags = repr(self._tags)
-        sourcelists = repr(self._sourcelists)
-        allow_duplicates = repr(self._allow_duplicates)
-        default_to_implicit_numbering = repr(self._default_to_implicit_numbering)
         # determine class name dynamically so that inherited classes
         # don't have to reimplement __repr__()
         return (
-            f"{self.__class__.__name__}({tags}, {sourcelists}, {allow_duplicates}, "
-            f"{default_to_implicit_numbering}, {self._default_source_number_digits})"
+            f"{self.__class__.__name__}({self._tags!r}, {self._sourcelists!r}, "
+            f"{self._allow_duplicates!r}, {self._default_to_implicit_numbering!r}, "
+            f"{self._default_source_number_digits!r}, {self._context!r})"
         )
 
+    def __deepcopy__(self, memo: Dict[int, Any]) -> "Sources":
+        result = self.__class__.__new__(self.__class__)
+        memo[id(self)] = result
+        for k, v in self.__dict__.items():
+            if k == "_context":
+                continue
+            setattr(result, k, copy.deepcopy(v, memo))
+        result._context = self._context
+        return result
+
     def __contains__(self, location: object) -> bool:
         items = self._get_items()
         if not items:
