@@ -158,7 +158,10 @@ class Specfile:
         self.path.write_text(str(self))
 
     def expand(
-        self, expression: str, extra_macros: Optional[List[Tuple[str, str]]] = None
+        self,
+        expression: str,
+        extra_macros: Optional[List[Tuple[str, str]]] = None,
+        skip_parsing: bool = False,
     ) -> str:
         """
         Expands an expression in the context of the spec file.
@@ -166,11 +169,15 @@ class Specfile:
         Args:
             expression: Expression to expand.
             extra_macros: Extra macros to be defined before expansion is performed.
+            skip_parsing: Do not parse the spec file before expansion is performed.
+              Defaults to False. Mutually exclusive with extra_macros. Set this to True
+              only if you are certain that the global macro context is up-to-date.
 
         Returns:
             Expanded expression.
         """
-        self._parser.parse(str(self), extra_macros)
+        if not skip_parsing:
+            self._parser.parse(str(self), extra_macros)
         return Macros.expand(expression)
 
     def get_active_macros(self) -> List[Macro]:
@@ -224,7 +231,7 @@ class Specfile:
             Spec file sections as `Sections` object.
         """
         with self.lines() as lines:
-            sections = Sections.parse(lines)
+            sections = Sections.parse(lines, context=self)
             try:
                 yield sections
             finally:
@@ -393,6 +400,7 @@ class Specfile:
         author: Optional[str] = None,
         email: Optional[str] = None,
         timestamp: Optional[Union[datetime.date, datetime.datetime]] = None,
+        evr: Optional[str] = None,
     ) -> None:
         """
         Adds a new %changelog entry. Does nothing if there is no %changelog section
@@ -407,15 +415,19 @@ class Specfile:
             email: E-mail of the author.
             timestamp: Timestamp of the entry.
               Supply `datetime` rather than `date` for extended format.
+            evr: Override the EVR part of the changelog entry.
+              Macros will be expanded automatically. By default, the function
+              determines the appropriate value based on the specfile's current
+              %{epoch}, %{version}, and %{release} values.
         """
         if self.has_autochangelog:
             return
+        if evr is None:
+            evr = "%{?epoch:%{epoch}:}%{version}-%{release}"
         with self.changelog() as changelog:
             if changelog is None:
                 return
-            evr = self.expand(
-                "%{?epoch:%{epoch}:}%{version}-%{release}", extra_macros=[("dist", "")]
-            )
+            evr = self.expand(evr, extra_macros=[("dist", "")])
             if isinstance(entry, str):
                 entry = [entry]
             if timestamp is None:
